@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-# Copyright 2009-2021 Joshua Bronson. All Rights Reserved.
+# Copyright 2009-2022 Joshua Bronson. All rights reserved.
 #
 # This Source Code Form is subject to the terms of the Mozilla Public
 # License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -15,13 +14,13 @@ __author__
 __maintainer__
 __copyright__
 __email__
-__credits__
 __description__
 __keywords__
 __license__
 __status__
 __url__
 __version__
+__project_urls__
 """.split()
 
 
